@@ -1,7 +1,7 @@
 package Path::Router;
 use Moose;
 
-our $VERSION   = '0.09';
+our $VERSION   = '0.10';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use File::Spec::Unix ();
@@ -18,6 +18,12 @@ has 'routes' => (
     default => sub { [] },
 );
 
+has 'route_class' => (
+    is      => 'ro',
+    isa     => 'ClassName',
+    default => 'Path::Router::Route',
+);
+
 has 'inline' => (
     is      => 'rw',
     isa     => 'Bool',
@@ -58,7 +64,7 @@ sub _build_match_code {
 
 sub add_route {
     my ($self, $path, %options) = @_;
-    push @{$self->routes} => Path::Router::Route->new(
+    push @{$self->routes} => $self->route_class->new(
         path  => $path,
         %options
     );
@@ -69,7 +75,7 @@ sub insert_route {
     my ($self, $path, %options) = @_;
     my $at = delete $options{at} || 0;
 
-    my $route = Path::Router::Route->new(
+    my $route = $self->route_class->new(
         path  => $path,
         %options
     );
@@ -409,7 +415,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 Infinity Interactive, Inc.
+Copyright 2008-2011 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
